@@ -9,7 +9,7 @@ use crate::EnvironmentSyncer;
 use futures_codec::FramedRead;
 use nu_errors::ShellError;
 use nu_protocol::hir::{ClassifiedCommand, Expression, InternalCommand, Literal, NamedArguments};
-use nu_protocol::{Primitive, ReturnSuccess, UntaggedValue, Value};
+use nu_protocol::{Primitive, ReturnSuccess, Scope, UntaggedValue, Value};
 
 use log::{debug, trace};
 #[cfg(feature = "rustyline-support")]
@@ -95,7 +95,7 @@ pub fn create_default_context(interactive: bool) -> Result<EvaluationContext, Bo
             whole_stream_command(Kill),
             whole_stream_command(Version),
             whole_stream_command(Clear),
-            whole_stream_command(What),
+            whole_stream_command(Describe),
             whole_stream_command(Which),
             whole_stream_command(Debug),
             whole_stream_command(Alias),
@@ -114,6 +114,8 @@ pub fn create_default_context(interactive: bool) -> Result<EvaluationContext, Bo
             whole_stream_command(Shells),
             whole_stream_command(Enter),
             whole_stream_command(Exit),
+            // Viz
+            whole_stream_command(Chart),
             // Viewers
             whole_stream_command(Autoview),
             whole_stream_command(Table),
@@ -145,7 +147,9 @@ pub fn create_default_context(interactive: bool) -> Result<EvaluationContext, Bo
             whole_stream_command(StrEndsWith),
             whole_stream_command(StrCollect),
             whole_stream_command(StrLength),
+            whole_stream_command(StrLPad),
             whole_stream_command(StrReverse),
+            whole_stream_command(StrRPad),
             whole_stream_command(StrCamelCase),
             whole_stream_command(StrPascalCase),
             whole_stream_command(StrKebabCase),
@@ -192,7 +196,7 @@ pub fn create_default_context(interactive: bool) -> Result<EvaluationContext, Bo
             whole_stream_command(Each),
             whole_stream_command(EachGroup),
             whole_stream_command(EachWindow),
-            whole_stream_command(IsEmpty),
+            whole_stream_command(Empty),
             // Table manipulation
             whole_stream_command(Move),
             whole_stream_command(Merge),
@@ -395,9 +399,7 @@ pub async fn cli(mut context: EvaluationContext) -> Result<(), Box<dyn Error>> {
                             &prompt_block.block,
                             &mut context,
                             InputStream::empty(),
-                            &Value::nothing(),
-                            &IndexMap::new(),
-                            &env,
+                            Scope::from_env(env),
                         )
                         .await
                         {
@@ -667,6 +669,9 @@ fn default_rustyline_editor_configuration() -> Editor<Helper> {
         Cmd::Move(Movement::ForwardWord(1, At::AfterEnd, Word::Vi)),
     );
 
+    // workaround for multiline-paste hang in rustyline (see https://github.com/kkawakam/rustyline/issues/202)
+    rl.bind_sequence(KeyPress::BracketedPasteStart, rustyline::Cmd::Noop);
+
     // Let's set the defaults up front and then override them later if the user indicates
     // defaults taken from here https://github.com/kkawakam/rustyline/blob/2fe886c9576c1ea13ca0e5808053ad491a6fe049/src/config.rs#L150-L167
     rl.set_max_history_size(100);
@@ -862,9 +867,7 @@ pub async fn parse_and_eval(line: &str, ctx: &mut EvaluationContext) -> Result<S
         &classified_block.block,
         ctx,
         input_stream,
-        &Value::nothing(),
-        &IndexMap::new(),
-        &env,
+        Scope::from_env(env),
     )
     .await?
     .collect_string(Tag::unknown())
@@ -1021,9 +1024,7 @@ pub async fn process_line(
             &classified_block.block,
             ctx,
             input_stream,
-            &Value::nothing(),
-            &IndexMap::new(),
-            &env,
+            Scope::from_env(env),
         )
         .await
         {
