@@ -5,6 +5,7 @@ pub mod max;
 pub mod median;
 pub mod min;
 pub mod mode;
+pub mod product;
 pub mod stddev;
 pub mod sum;
 pub mod variance;
@@ -19,6 +20,7 @@ pub use max::SubCommand as MathMaximum;
 pub use median::SubCommand as MathMedian;
 pub use min::SubCommand as MathMinimum;
 pub use mode::SubCommand as MathMode;
+pub use product::SubCommand as MathProduct;
 pub use stddev::SubCommand as MathStddev;
 pub use sum::SubCommand as MathSummation;
 pub use variance::SubCommand as MathVariance;
