@@ -36,11 +36,12 @@ impl WholeStreamCommand for Path {
 #[cfg(test)]
 mod tests {
     use super::Path;
+    use super::ShellError;
 
     #[test]
-    fn examples_work_as_expected() {
+    fn examples_work_as_expected() -> Result<(), ShellError> {
         use crate::examples::test as test_examples;
 
-        test_examples(Path {})
+        Ok(test_examples(Path {})?)
     }
 }
