@@ -50,11 +50,12 @@ pub async fn pwd(
 #[cfg(test)]
 mod tests {
     use super::Pwd;
+    use super::ShellError;
 
     #[test]
-    fn examples_work_as_expected() {
+    fn examples_work_as_expected() -> Result<(), ShellError> {
         use crate::examples::test as test_examples;
 
-        test_examples(Pwd {})
+        Ok(test_examples(Pwd {})?)
     }
 }
