@@ -102,16 +102,17 @@ fn action(input: &Value, pattern: &str, tag: impl Into<Tag>) -> Result<Value, Sh
 
 #[cfg(test)]
 mod tests {
+    use super::ShellError;
     use super::{action, SubCommand};
     use nu_plugin::test_helpers::value::string;
     use nu_protocol::UntaggedValue;
     use nu_source::Tag;
 
     #[test]
-    fn examples_work_as_expected() {
+    fn examples_work_as_expected() -> Result<(), ShellError> {
         use crate::examples::test as test_examples;
 
-        test_examples(SubCommand {})
+        Ok(test_examples(SubCommand {})?)
     }
 
     #[test]
