@@ -77,12 +77,13 @@ async fn touch(args: CommandArgs, registry: &CommandRegistry) -> Result<OutputSt
 
 #[cfg(test)]
 mod tests {
+    use super::ShellError;
     use super::Touch;
 
     #[test]
-    fn examples_work_as_expected() {
+    fn examples_work_as_expected() -> Result<(), ShellError> {
         use crate::examples::test as test_examples;
 
-        test_examples(Touch {})
+        Ok(test_examples(Touch {})?)
     }
 }
