@@ -138,12 +138,13 @@ async fn wrap(args: CommandArgs, registry: &CommandRegistry) -> Result<OutputStr
 
 #[cfg(test)]
 mod tests {
+    use super::ShellError;
     use super::Wrap;
 
     #[test]
-    fn examples_work_as_expected() {
+    fn examples_work_as_expected() -> Result<(), ShellError> {
         use crate::examples::test as test_examples;
 
-        test_examples(Wrap {})
+        Ok(test_examples(Wrap {})?)
     }
 }
