@@ -1,5 +1,6 @@
 use crate::command_registry::CommandRegistry;
 use crate::commands::classified::block::run_block;
+use crate::did_you_mean;
 use crate::evaluate::operator::apply_operator;
 use crate::prelude::*;
 use async_recursion::async_recursion;
@@ -7,16 +8,14 @@ use log::trace;
 use nu_errors::{ArgumentError, ShellError};
 use nu_protocol::hir::{self, Expression, ExternalRedirection, RangeOperator, SpannedExpression};
 use nu_protocol::{
-    ColumnPath, Primitive, RangeInclusion, UnspannedPathMember, UntaggedValue, Value,
+    ColumnPath, Primitive, RangeInclusion, Scope, UnspannedPathMember, UntaggedValue, Value,
 };
 
 #[async_recursion]
 pub(crate) async fn evaluate_baseline_expr(
     expr: &SpannedExpression,
     registry: &CommandRegistry,
-    it: &Value,
-    vars: &IndexMap<String, Value>,
-    env: &IndexMap<String, String>,
+    scope: Arc<Scope>,
 ) -> Result<Value, ShellError> {
     let tag = Tag {
         span: expr.span,
@@ -33,14 +32,14 @@ pub(crate) async fn evaluate_baseline_expr(
         Expression::Synthetic(hir::Synthetic::String(s)) => {
             Ok(UntaggedValue::string(s).into_untagged_value())
         }
-        Expression::Variable(var) => evaluate_reference(&var, it, vars, env, tag),
+        Expression::Variable(var) => evaluate_reference(&var, scope, tag),
         Expression::Command => unimplemented!(),
-        Expression::Invocation(block) => evaluate_invocation(block, registry, it, vars, env).await,
+        Expression::Invocation(block) => evaluate_invocation(block, registry, scope).await,
         Expression::ExternalCommand(_) => unimplemented!(),
         Expression::Binary(binary) => {
             // TODO: If we want to add short-circuiting, we'll need to move these down
-            let left = evaluate_baseline_expr(&binary.left, registry, it, vars, env).await?;
-            let right = evaluate_baseline_expr(&binary.right, registry, it, vars, env).await?;
+            let left = evaluate_baseline_expr(&binary.left, registry, scope.clone()).await?;
+            let right = evaluate_baseline_expr(&binary.right, registry, scope).await?;
 
             trace!("left={:?} right={:?}", left.value, right.value);
 
@@ -62,13 +61,13 @@ pub(crate) async fn evaluate_baseline_expr(
         }
         Expression::Range(range) => {
             let left = if let Some(left) = &range.left {
-                evaluate_baseline_expr(&left, registry, it, vars, env).await?
+                evaluate_baseline_expr(&left, registry, scope.clone()).await?
             } else {
                 Value::nothing()
             };
 
             let right = if let Some(right) = &range.right {
-                evaluate_baseline_expr(&right, registry, it, vars, env).await?
+                evaluate_baseline_expr(&right, registry, scope).await?
             } else {
                 Value::nothing()
             };
@@ -94,7 +93,7 @@ pub(crate) async fn evaluate_baseline_expr(
             let mut output_headers = vec![];
 
             for expr in headers {
-                let val = evaluate_baseline_expr(&expr, registry, it, vars, env).await?;
+                let val = evaluate_baseline_expr(&expr, registry, scope.clone()).await?;
 
                 let header = val.as_string()?;
                 output_headers.push(header);
@@ -122,7 +121,7 @@ pub(crate) async fn evaluate_baseline_expr(
 
                 let mut row_output = IndexMap::new();
                 for cell in output_headers.iter().zip(row.iter()) {
-                    let val = evaluate_baseline_expr(&cell.1, registry, it, vars, env).await?;
+                    let val = evaluate_baseline_expr(&cell.1, registry, scope.clone()).await?;
                     row_output.insert(cell.0.clone(), val);
                 }
                 output_table.push(UntaggedValue::row(row_output).into_value(tag.clone()));
@@ -134,7 +133,7 @@ pub(crate) async fn evaluate_baseline_expr(
             let mut exprs = vec![];
 
             for expr in list {
-                let expr = evaluate_baseline_expr(&expr, registry, it, vars, env).await?;
+                let expr = evaluate_baseline_expr(&expr, registry, scope.clone()).await?;
                 exprs.push(expr);
             }
 
@@ -142,7 +141,7 @@ pub(crate) async fn evaluate_baseline_expr(
         }
         Expression::Block(block) => Ok(UntaggedValue::Block(block.clone()).into_value(&tag)),
         Expression::Path(path) => {
-            let value = evaluate_baseline_expr(&path.head, registry, it, vars, env).await?;
+            let value = evaluate_baseline_expr(&path.head, registry, scope).await?;
             let mut item = value;
 
             for member in &path.tail {
@@ -150,24 +149,18 @@ pub(crate) async fn evaluate_baseline_expr(
 
                 match next {
                     Err(err) => {
-                        let possibilities = item.data_descriptors();
+                        if let UnspannedPathMember::String(_name) = &member.unspanned {
+                            let possible_matches = did_you_mean(&item, member.as_string());
 
-                        if let UnspannedPathMember::String(name) = &member.unspanned {
-                            let mut possible_matches: Vec<_> = possibilities
-                                .iter()
-                                .map(|x| (natural::distance::levenshtein_distance(x, &name), x))
-                                .collect();
-
-                            possible_matches.sort();
-
-                            if !possible_matches.is_empty() {
-                                return Err(ShellError::labeled_error(
-                                    "Unknown column",
-                                    format!("did you mean '{}'?", possible_matches[0].1),
-                                    &member.span,
-                                ));
-                            } else {
-                                return Err(err);
+                            match possible_matches {
+                                Some(p) => {
+                                    return Err(ShellError::labeled_error(
+                                        "Unknown column",
+                                        format!("did you mean '{}'?", p[0]),
+                                        &member.span,
+                                    ));
+                                }
+                                None => return Err(err),
                             }
                         }
                     }
@@ -208,15 +201,20 @@ fn evaluate_literal(literal: &hir::Literal, span: Span) -> Value {
 
 fn evaluate_reference(
     name: &hir::Variable,
-    it: &Value,
-    vars: &IndexMap<String, Value>,
-    env: &IndexMap<String, String>,
+    scope: Arc<Scope>,
     tag: Tag,
 ) -> Result<Value, ShellError> {
     match name {
-        hir::Variable::It(_) => Ok(it.clone()),
+        hir::Variable::It(_) => match scope.it() {
+            Some(v) => Ok(v),
+            None => Err(ShellError::labeled_error(
+                "$it variable not in scope",
+                "not in scope (are you missing an 'each'?)",
+                tag.span,
+            )),
+        },
         hir::Variable::Other(name, _) => match name {
-            x if x == "$nu" => crate::evaluate::variables::nu(env, tag),
+            x if x == "$nu" => crate::evaluate::variables::nu(&scope.env(), tag),
             x if x == "$true" => Ok(Value {
                 value: UntaggedValue::boolean(true),
                 tag,
@@ -225,10 +223,14 @@ fn evaluate_reference(
                 value: UntaggedValue::boolean(false),
                 tag,
             }),
-            x => Ok(vars
-                .get(x)
-                .cloned()
-                .unwrap_or_else(|| UntaggedValue::nothing().into_value(tag))),
+            x => match scope.var(x) {
+                Some(v) => Ok(v),
+                None => Err(ShellError::labeled_error(
+                    "Variable not in scope",
+                    "unknown variable",
+                    tag.span,
+                )),
+            },
         },
     }
 }
@@ -236,20 +238,21 @@ fn evaluate_reference(
 async fn evaluate_invocation(
     block: &hir::Block,
     registry: &CommandRegistry,
-    it: &Value,
-    vars: &IndexMap<String, Value>,
-    env: &IndexMap<String, String>,
+    scope: Arc<Scope>,
 ) -> Result<Value, ShellError> {
     // FIXME: we should use a real context here
     let mut context = EvaluationContext::basic()?;
     context.registry = registry.clone();
 
-    let input = InputStream::one(it.clone());
+    let input = match scope.it() {
+        Some(it) => InputStream::one(it),
+        None => InputStream::empty(),
+    };
 
     let mut block = block.clone();
     block.set_redirect(ExternalRedirection::Stdout);
 
-    let result = run_block(&block, &mut context, input, it, vars, env).await?;
+    let result = run_block(&block, &mut context, input, scope).await?;
 
     let output = result.into_vec().await;
 
