@@ -1,6 +1,13 @@
-use crate::completion::{self, Suggestion};
-use crate::context;
-use std::fs::metadata;
+use crate::completion::command::CommandCompleter;
+use crate::completion::flag::FlagCompleter;
+use crate::completion::matchers;
+use crate::completion::matchers::Matcher;
+use crate::completion::path::{PathCompleter, PathSuggestion};
+use crate::completion::{self, Completer, Suggestion};
+use crate::evaluation_context::EvaluationContext;
+use nu_source::Tag;
+
+use std::borrow::Cow;
 
 pub(crate) struct NuCompleter {}
 
@@ -11,11 +18,11 @@ impl NuCompleter {
         &self,
         line: &str,
         pos: usize,
-        context: &completion::Context,
+        context: &completion::CompletionContext,
     ) -> (usize, Vec<Suggestion>) {
-        use crate::completion::engine::LocationType;
+        use completion::engine::LocationType;
 
-        let nu_context: &context::Context = context.as_ref();
+        let nu_context: &EvaluationContext = context.as_ref();
         let lite_block = match nu_parser::lite_parse(line, 0) {
             Ok(block) => Some(block),
             Err(result) => result.partial,
@@ -23,9 +30,25 @@ impl NuCompleter {
 
         let locations = lite_block
             .map(|block| nu_parser::classify_block(&block, &nu_context.registry))
-            .map(|block| crate::completion::engine::completion_location(line, &block.block, pos))
+            .map(|block| completion::engine::completion_location(line, &block.block, pos))
             .unwrap_or_default();
 
+        let matcher = nu_data::config::config(Tag::unknown())
+            .ok()
+            .and_then(|cfg| cfg.get("line_editor").cloned())
+            .and_then(|le| {
+                le.row_entries()
+                    .find(|(idx, _value)| idx.as_str() == "completion_match_method")
+                    .and_then(|(_idx, value)| value.as_string().ok())
+            })
+            .unwrap_or_else(String::new);
+
+        let matcher = matcher.as_str();
+        let matcher: &dyn Matcher = match matcher {
+            "case-insensitive" => &matchers::case_insensitive::Matcher,
+            _ => &matchers::case_sensitive::Matcher,
+        };
+
         if locations.is_empty() {
             (pos, Vec::new())
         } else {
@@ -36,17 +59,17 @@ impl NuCompleter {
                     let partial = location.span.slice(line);
                     match location.item {
                         LocationType::Command => {
-                            let command_completer = crate::completion::command::Completer;
-                            command_completer.complete(context, partial)
+                            let command_completer = CommandCompleter;
+                            command_completer.complete(context, partial, matcher.to_owned())
                         }
 
                         LocationType::Flag(cmd) => {
-                            let flag_completer = crate::completion::flag::Completer;
-                            flag_completer.complete(context, cmd, partial)
+                            let flag_completer = FlagCompleter { cmd };
+                            flag_completer.complete(context, partial, matcher.to_owned())
                         }
 
                         LocationType::Argument(cmd, _arg_name) => {
-                            let path_completer = crate::completion::path::Completer;
+                            let path_completer = PathCompleter;
 
                             const QUOTE_CHARS: &[char] = &['\'', '"', '`'];
 
@@ -71,15 +94,15 @@ impl NuCompleter {
                                 partial
                             };
 
-                            let completed_paths = path_completer.complete(context, partial);
+                            let completed_paths = path_completer.path_suggestions(partial, matcher);
                             match cmd.as_deref().unwrap_or("") {
                                 "cd" => select_directory_suggestions(completed_paths),
                                 _ => completed_paths,
                             }
                             .into_iter()
-                            .map(|suggestion| Suggestion {
-                                replacement: requote(suggestion.replacement),
-                                display: suggestion.display,
+                            .map(|s| Suggestion {
+                                replacement: requote(s.suggestion.replacement),
+                                display: s.suggestion.display,
                             })
                             .collect()
                         }
@@ -94,19 +117,21 @@ impl NuCompleter {
     }
 }
 
-fn select_directory_suggestions(completed_paths: Vec<Suggestion>) -> Vec<Suggestion> {
+fn select_directory_suggestions(completed_paths: Vec<PathSuggestion>) -> Vec<PathSuggestion> {
     completed_paths
         .into_iter()
         .filter(|suggestion| {
-            metadata(&suggestion.replacement)
+            suggestion
+                .path
+                .metadata()
                 .map(|md| md.is_dir())
                 .unwrap_or(false)
         })
         .collect()
 }
 
-fn requote(value: String) -> String {
-    let value = rustyline::completion::unescape(&value, Some('\\'));
+fn requote(orig_value: String) -> String {
+    let value: Cow<str> = rustyline::completion::unescape(&orig_value, Some('\\'));
 
     let mut quotes = vec!['"', '\'', '`'];
     let mut should_quote = false;
