@@ -12,6 +12,7 @@ mod default;
 mod drop;
 mod each;
 mod echo;
+mod empty;
 mod enter;
 mod every;
 mod first;
@@ -22,7 +23,6 @@ mod headers;
 mod histogram;
 mod insert;
 mod into_int;
-mod is_empty;
 mod keep;
 mod last;
 mod lines;
